#
# spec file for package ltris
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ltris
Version:        1.3.2
Release:        1.1
Summary:        Tetris Clone with Multiplayer and CPU Opponents
License:        GPL-2.0-or-later
Group:          Amusements/Games/Logic
URL:            http://lgames.sourceforge.net/index.php?project=LTris
Source:         https://sourceforge.net/projects/lgames/files/ltris/ltris-%{version}.tar.gz
Source1:        %{name}.desktop
Patch0:         ltris-no_system_wide_hiscore_file.patch
# PATCH-FIX-UPSTREAM ltris-gamepad-pause-exit.patch badshah400@gmail.com -- Interpret pause button from gamepad (https://sourceforge.net/p/lgames/patches/35/)
Patch1:         ltris-gamepad-pause-exit.patch
BuildRequires:  SDL-devel
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL_mixer)

%description
LTris is a very polished Tetris clone. It is highly configurable due to
its menu. It offers the well-known game type Classic, a funny game type
Figures (a new figure each level, suddenly appearing tiles and lines),
and multiplayer with up to three players either human or CPU
controlled.

%prep
%autosetup -p1
# we patch both Makefile.am and Makefile.in; touch Makefile.in here again
# to make sure configure won't run autoreconf (which it does if the .am file
# is newer than the .in file):
touch src/Makefile.in

%build
export CFLAGS="%{optflags} -fPIC -fPIE"
export CXXFLAGS="$CFLAGS"
export LDFLAGS="-pie"
%configure \
  --datadir=%{_datadir}/games \
  --localstatedir=%{_localstatedir}/games
%make_build

%install
%make_install
install -D -m 0644 icons/ltris48.xpm %{buildroot}%{_datadir}/pixmaps/ltris.xpm
mv %{buildroot}%{_datadir}/games/locale %{buildroot}%{_datadir}/locale
rm -rf "%{buildroot}%{_datadir}/games/applications"
rm -rf "%{buildroot}%{_datadir}/games/icons"
%fdupes -s "%{buildroot}%{_datadir}/games/ltris"
%suse_update_desktop_file -i %{name} Game ArcadeGame
%find_lang %{name}

%files -f %{name}.lang
%license COPYING
%doc AUTHORS ChangeLog README
%{_bindir}/ltris
%{_datadir}/games/ltris/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/ltris.xpm

%changelog
* Thu Jun 20 2024 Atri Bhattacharya <badshah400@gmail.com>
- Add ltris-gamepad-pause-exit.patch: Interpret pause button from
  gamepad (https://sourceforge.net/p/lgames/patches/35/).
* Sun Jun  9 2024 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.3.2
  * use AM_PATH_SDL and SDL_CONFIG again
  * updated icon location
* Wed Apr 24 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.3.1
  * updated german translation.
  * show stats for all players after game finished.
  * properly increase level in game mode Figures.
  * fixed bug in creating new figures in game mode Figures.
  * leave game over screen only with ESC, SPACE or RETURN.
  * removed AC_CANONICAL_TARGET from configure.ac.
  * updated icon location.
  * updated LTris appstream metadata.
* Fri Mar 22 2024 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.3
  * cpu algorithm uses hold option
  * tweaked cpu algorithm
* Sat Feb 17 2024 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.2.8
  * fixed bug in sending lines in multiplayer
  * tweaked multiplayer defaults
  * added option to customize cpu drop speed
  * do not show special piece on lock delay if soft drop pressed
  * properly insert/lock pieces if dropping more than one tile
* Sat Sep  9 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.7
  * Some minor fixes for the configuration process
  * Icons are installed properly and the obsolete intl directory
    has been removed.
* Tue Oct  4 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.6:
  * reset lock delay on hold.
* Sun Jun 19 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.5:
  * added hold feature.
  * updated german translation.
  * fixed crash with odd resolutions.
* Sat Apr 16 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.2.4:
  - replaced DAS option with auto shift delay/speed options
  - allow q key for controls
- Switched from pkgconfig(sdl) to SDL-devel to solve have choice
  for pkgconfig(sdl): SDL-devel libSDL-devel
* Sun Apr 11 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.3:
  * added gamepad support (not configurable via menu yet).
  * show three pieces as preview for modern style.
  * updated some menu hints.
  * added configure option --with-configdir.
  * added ltris.appdata.xml.
  * show stats only for game modes with one bowl.
* Mon Dec 28 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.2:
  * don't redraw stack in pause after animation
  * avoid odd resolutions like 1366x768
  * console option for fullscreen
  * cleaned up configure
  * improved wall kicks
  * added lock delay
  * allow more keys for controls
  * added hyper DAS option
* Mon Aug  3 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.2.1:
  * fixed build failure with gcc 4.8 (2020/07/27 Fabrice Fontaine)
  * added training mode with optional zero gravity (2020/07/01 MS)
* Sun Jul  5 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 1.2:
  * added classic game style: no wall-kicks, random pieces,
    no shadow piece, ...
  * added auto-delay shift (das) and are (entry delay)
  * menu simplified
  * code cleanups
  * statistics for single player mode
  * fixed compiler warnings
- Rebase ltris-no_system_wide_hiscore_file.patch
* Sat Jun 20 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.20:
  * updated configure.in to configure.ac
  * added wide screen support
  * removed all inline keywords to work with GCC 5
- Remove not longer needed patch:
  * ltris-fix-with-gcc5.patch
- Specfile cleanup
* Sat Jan  2 2016 rpm@fthiessen.de
- Update to 1.0.19:
  * removed link to lib math as not needed
  * reset key states when unpausing to prevent unwanted movement
- Added ltris-fix-with-gcc5.patch to fix build with gcc 5 -- changed
  inline function handling.
* Thu Apr 18 2013 joop.boonen@opensuse.org
- Adapted the License according to the spdx standard
* Mon Oct 31 2011 pascal.bleser@opensuse.org
- moved binary to %%{_bindir} instead of %%{_prefix}/games
- patched ltris to prevent it from trying to save the highscores to a
  system-wide file
- ltris no longer runs as SUID/GUID games, but as the regular user, as
  highscores are now only stored in the home directory
* Mon Oct 31 2011 pascal.bleser@opensuse.org
- update to 1.0.18:
  * adds an option to configure vertical speed for moving blocks down by key,
    as they drop too quickly on fast computers
* Thu Sep  1 2011 pascal.bleser@opensuse.org
- update to 1.0.17:
  * the key for pausing the game, previously fixed to P, is now configurable
  * if rotation of a block would fail because of a left or right boundary, the
    block is shifted instead of not rotating at all
  * the "Game Over" screen can be exited via any key, not just Escape
* Sat Jul  2 2011 jengelh@medozas.de
- Use %%_smp_mflags for parallel building
- Strip %%clean section (not needed on BS)
* Thu Mar  3 2011 pascal.bleser@opensuse.org
- update to 1.0.16
  * improved random number generator
  * generate pieces according to official Tetris guidelines
  * always deal same sequence of pieces to all players
  * in expert mode deal most unsuitable piece out of current bag instead of
    random piece
- changes from 1.0.15:
  * added italian localization
- changes from 1.0.14:
  * increased range for horizontal block delay to 9
  * fixed incorrect english (penalty instead of malus)
  * added XDG support
* Sat Nov  7 2009 dimstar@opensuse.org
- Verify the permissions set by the permissions package
  (verfiy_permissions and run_permissions)
* Sat Nov  7 2009 pascal.bleser@opensuse.org
- update to 1.0.13:
  * block drop shadow is now enabled by default
  * Swedish and French translations were added
  * translation-independent chart IDs are now used
* Wed Apr  2 2008 prusnak@suse.cz
- updated to 1.0.12
  * added portugese translation
  * l10n of yes/no keys
* Sun Mar 16 2008 crrodriguez@suse.de
- fix file-not-in-lang problems
* Fri Mar  9 2007 ltinkl@suse.cz
- fix #252072 - ltris installs locales into the wrong directory
* Wed Mar  7 2007 ltinkl@suse.cz
- update to 1.0.11, fix build
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Sep 21 2005 pnemec@suse.cz
- fixed icon and desktop file #113656
* Mon Feb 21 2005 mcihar@suse.cz
- update to 1.0.10
* Mon Feb  7 2005 mcihar@suse.cz
- update to 1.0.9
* Wed Aug  4 2004 mcihar@suse.cz
- update to 1.0.7
* Tue Feb 24 2004 mcihar@suse.cz
- update to 1.0.6
* Wed Oct 29 2003 mcihar@suse.cz
- added the missing Prereq for "permissions"
- added the missing verifyscript
* Wed Oct 29 2003 mcihar@suse.cz
- no root for build
* Mon Oct 27 2003 ro@suse.de
- package according to permissions.secure and add %%run_permissions
* Tue Oct 14 2003 mcihar@suse.cz
- moved to /usr/games
- updated to 1.0.5:
  - windows manager's close button works
  - expert mode with unbalanced properties for next block to make it
    difficult to fit
* Sun Aug 10 2003 sndirsch@suse.de
- added desktop file
* Thu May 29 2003 mcihar@suse.cz
- hiscores don't need to be executable
* Wed Jan 22 2003 mcihar@suse.cz
- updated to 1.0.4 (bugfix release)
* Tue Aug  6 2002 mcihar@suse.cz
- updated to 1.0.3:
  * fixed some two-player bug
  * fixed typos
  * support for other audio buffer size
  * optional asynchron collision check
* Tue Jul 30 2002 kukuk@suse.de
- use group games instead of game
* Tue Jan 22 2002 ro@suse.de
- changed neededforbuild <kdelibs-artsd> to <kdelibs3-artsd>
* Fri Jan 18 2002 cihlar@suse.cz
- update to version 1.0.1
* Tue Nov  6 2001 cihlar@suse.cz
- fixed to compile with automake 1.5
* Wed Aug  8 2001 ro@suse.de
- updated neededforbuild
* Wed Jun 20 2001 cihlar@suse.cz
- added kdelibs and kdelibs-devel to neededforbuild
* Mon Apr  9 2001 cihlar@suse.cz
- updated to version 010310
* Mon Mar 26 2001 ro@suse.de
- added sdl-devel to neededforbuild
* Wed Feb 21 2001 cihlar@suse.cz
- added alsa, esound and audiofile to neededforbuild
* Mon Dec  4 2000 cihlar@suse.cz
- package created
